pub struct HighlightSelection {
pub node_indices: BTreeSet<usize>,
pub edge_indices: BTreeSet<usize>,
}Expand description
Exact graph elements to keep vivid in a highlighted SNFG rendering.
Indices are the stable petgraph node/edge indices exposed by the source
ResidueGraph; elements not listed here are rendered with the muted SNFG
palette.
Fields
node_indices: BTreeSet<usize>edge_indices: BTreeSet<usize>Trait Implementations
Sourceimpl Clone for HighlightSelection
impl Clone for HighlightSelection
Sourcefn clone(&self) -> HighlightSelection
fn clone(&self) -> HighlightSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HighlightSelection
impl Debug for HighlightSelection
Sourceimpl Default for HighlightSelection
impl Default for HighlightSelection
Sourcefn default() -> HighlightSelection
fn default() -> HighlightSelection
Returns the “default value” for a type. Read more
impl Eq for HighlightSelection
Sourceimpl PartialEq for HighlightSelection
impl PartialEq for HighlightSelection
impl StructuralPartialEq for HighlightSelection